@@ -113,8 +113,11 @@ Ticket.get_relations('concerns').next().constraints = [
     ]
 
 # client can only modify tickets when they are in the "open" state
-Ticket.__permissions__['update'] = ('managers', 'staff', xexpr('developer'),
-                                ERQLExpression(xperm('client')+', X in_state S, S name "open"'))
+Ticket.__permissions__['update'] = ('managers', 'staff',
+                                    xexpr('developer'),
+                                    ERQLExpression(xperm('client')+', X in_state S, S name "open"'),
+                                    ERQLExpression('X owned_by U, X in_state S, S name "open"'),
+                                    )
 
 Version.add_relation(Float(description=_('computed attribute'), default=0), name='progress_target')
 Version.add_relation(Float(description=_('computed attribute'), default=0), name='progress_done')
@@ -195,29 +198,25 @@ class see_also(RelationDefinition):
     object = ('ExtProject', 'Project', 'Ticket', 'Card', 'File', 'Image',
               'Email')
 
-class missing_comments(RelationDefinition):
+class comments(RelationDefinition):
     subject = 'Comment'
-    name = 'comments'
     object = ('Card', 'File', 'Image', 'Email')
     cardinality = '1*'
     composite = 'object'
 
 
-class missing_tags(RelationDefinition):
-    name = 'tags'
+class tags(RelationDefinition):
     subject = 'Tag'
     object = ('ExtProject', 'Project', 'Version', 'Ticket',
               'License', 'MailingList',
               'Card', 'File', 'Image', 'Email')
 
-class missing_filed_under(RelationDefinition):
-    name = 'filed_under'
+class filed_under(RelationDefinition):
     subject = ('ExtProject', 'Project', 'Card', 'File')
     object = 'Folder'
 
-class missing_require_permission(RelationDefinition):
-    name = 'require_permission'
-    subject = ('ExtProject', 'Comment', 'Image', 'File', 'Card')
+class require_permission(RelationDefinition):
+    subject = ('ExtProject', 'Comment', 'Image', 'File', 'Card', 'TestInstance')
     object = 'CWPermission'
 
 # relation types permissions ##################################################
